@@ -197,7 +197,7 @@ class Text(Column):
     db_type = 'text'
 
     def __init__(self, *args, **kwargs):
-        self.min_length = kwargs.pop('min_length', 1 if kwargs.get('required', True) else None)
+        self.min_length = kwargs.pop('min_length', 1 if kwargs.get('required', False) else None)
         self.max_length = kwargs.pop('max_length', None)
         super(Text, self).__init__(*args, **kwargs)
 
