@@ -154,6 +154,39 @@ class LessThanOrEqualOperator(QueryOperator):
     symbol = "LTE"
     cql_symbol = '<='
 
+class AbstractQueryableColumn(object):
+    """
+    exposes cql query operators through pythons
+    builtin comparator symbols
+    """
+
+    def _get_column(self):
+        raise NotImplementedError
+
+    def in_(self, item):
+        """
+        Returns an in operator
+
+        used in where you'd typically want to use python's `in` operator
+        """
+        return InOperator(self._get_column(), item)
+
+    def __eq__(self, other):
+        return EqualsOperator(self._get_column(), other)
+
+    def __gt__(self, other):
+        return GreaterThanOperator(self._get_column(), other)
+
+    def __ge__(self, other):
+        return GreaterThanOrEqualOperator(self._get_column(), other)
+
+    def __lt__(self, other):
+        return LessThanOperator(self._get_column(), other)
+
+    def __le__(self, other):
+        return LessThanOrEqualOperator(self._get_column(), other)
+
+
 class BatchType(object):
     Unlogged    = 'UNLOGGED'
     Counter     = 'COUNTER'
@@ -206,10 +239,11 @@ class BatchQuery(object):
         if exc_type is not None: return
         self.execute()
 
-class QuerySet(object):
+
+class AbstractQuerySet(object):
 
     def __init__(self, model):
-        super(QuerySet, self).__init__()
+        super(AbstractQuerySet, self).__init__()
         self.model = model
 
         #Where clause filters
@@ -249,8 +283,8 @@ class QuerySet(object):
     def __str__(self):
         return str(self.__unicode__())
 
-    def __call__(self, **kwargs):
-        return self.filter(**kwargs)
+    def __call__(self, *args, **kwargs):
+        return self.filter(*args, **kwargs)
 
     def __deepcopy__(self, memo):
         clone = self.__class__(self.model)
@@ -280,29 +314,8 @@ class QuerySet(object):
 
     #----query generation / execution----
 
-    def _validate_where_syntax(self):
-        """ Checks that a filterset will not create invalid cql """
-
-        #check that there's either a = or IN relationship with a primary key or indexed field
-        equal_ops = [w for w in self._where if isinstance(w, EqualsOperator)]
-        token_ops = [w for w in self._where if isinstance(w.value, Token)]
-        if not any([w.column.primary_key or w.column.index for w in equal_ops]) and not token_ops:
-            raise QueryException('Where clauses require either a "=" or "IN" comparison with either a primary key or indexed field')
-
-        if not self._allow_filtering:
-            #if the query is not on an indexed field
-            if not any([w.column.index for w in equal_ops]):
-                if not any([w.column.partition_key for w in equal_ops]) and not token_ops:
-                    raise QueryException('Filtering on a clustering key without a partition key is not allowed unless allow_filtering() is called on the querset')
-            if any(not w.column.partition_key for w in token_ops):
-                raise QueryException('The token() function is only supported on the partition key')
-
-
-        #TODO: abuse this to see if we can get cql to raise an exception
-
     def _where_clause(self):
         """ Returns a where clause based on the given filter args """
-        self._validate_where_syntax()
         return ' AND '.join([f.cql for f in self._where])
 
     def _where_values(self):
@@ -312,18 +325,15 @@ class QuerySet(object):
             values.update(where.get_dict())
         return values
 
+    def _get_select_statement(self):
+        """ returns the select portion of this queryset's cql statement """
+        raise NotImplementedError
+
     def _select_query(self):
         """
         Returns a select clause based on the given filter args
         """
-        fields = self.model._columns.keys()
-        if self._defer_fields:
-            fields = [f for f in fields if f not in self._defer_fields]
-        elif self._only_fields:
-            fields = self._only_fields
-        db_fields = [self.model._columns[f].db_field_name for f in fields]
-
-        qs = ['SELECT {}'.format(', '.join(['"{}"'.format(f) for f in db_fields]))]
+        qs = [self._get_select_statement()]
         qs += ['FROM {}'.format(self.column_family_name)]
 
         if self._where:
@@ -410,22 +420,7 @@ class QuerySet(object):
         """
         Returns a function that will be used to instantiate query results
         """
-        model = self.model
-        db_map = model._db_map
-        if not self._values_list:
-            def _construct_instance(values):
-                field_dict = dict((db_map.get(k, k), v) for k, v in zip(names, values))
-                instance = model(**field_dict)
-                instance._is_persisted = True
-                return instance
-            return _construct_instance
-
-        columns = [model._columns[db_map[name]] for name in names]
-        if self._flat_values_list:
-           return (lambda values: columns[0].to_python(values[0]))
-        else:
-            # result_cls = namedtuple("{}Tuple".format(self.model.__name__), names)
-            return (lambda values: map(lambda (c, v): c.to_python(v), zip(columns, values)))
+        raise NotImplementedError
 
     def batch(self, batch_obj):
         """
@@ -462,14 +457,26 @@ class QuerySet(object):
         else:
             raise QueryException("Can't parse '{}'".format(arg))
 
-    def filter(self, **kwargs):
+    def filter(self, *args, **kwargs):
+        """
+        Adds WHERE arguments to the queryset, returning a new queryset
+
+        #TODO: show examples
+
+        :rtype: AbstractQuerySet
+        """
         #add arguments to the where clause filters
         clone = copy.deepcopy(self)
+        for operator in args:
+            if not isinstance(operator, QueryOperator):
+                raise QueryException('{} is not a valid query operator'.format(operator))
+            clone._where.append(operator)
+
         for arg, val in kwargs.items():
             col_name, col_op = self._parse_filter_arg(arg)
             #resolve column and operator
             try:
-                column = self.model._columns[col_name]
+                column = self.model._get_column(col_name)
             except KeyError:
                 if col_name == 'pk__token':
                     column = columns._PartitionKeysToken(self.model)
@@ -484,14 +491,16 @@ class QuerySet(object):
 
         return clone
 
-    def get(self, **kwargs):
+    def get(self, *args, **kwargs):
         """
         Returns a single instance matching this query, optionally with additional filter kwargs.
 
         A DoesNotExistError will be raised if there are no rows matching the query
         A MultipleObjectsFoundError will be raised if there is more than one row matching the queyr
         """
-        if kwargs: return self.filter(**kwargs).get()
+        if args or kwargs:
+            return self.filter(*args, **kwargs).get()
+
         self._execute_query()
         if len(self._result_cache) == 0:
             raise self.model.DoesNotExist
@@ -501,6 +510,12 @@ class QuerySet(object):
         else:
             return self[0]
 
+    def _get_ordering_condition(self, colname):
+        order_type = 'DESC' if colname.startswith('-') else 'ASC'
+        colname = colname.replace('-', '')
+
+        return colname, order_type
+
     def order_by(self, *colnames):
         """
         orders the result set.
@@ -515,24 +530,7 @@ class QuerySet(object):
 
         conditions = []
         for colname in colnames:
-            order_type = 'DESC' if colname.startswith('-') else 'ASC'
-            colname = colname.replace('-', '')
-
-            column = self.model._columns.get(colname)
-            if column is None:
-                raise QueryException("Can't resolve the column name: '{}'".format(colname))
-
-            #validate the column selection
-            if not column.primary_key:
-                raise QueryException(
-                    "Can't order on '{}', can only order on (clustered) primary keys".format(colname))
-
-            pks = [v for k, v in self.model._columns.items() if v.primary_key]
-            if column == pks[0]:
-                raise QueryException(
-                    "Can't order by the first primary key (partition key), clustering (secondary) keys only")
-
-            conditions.append('"{}" {}'.format(column.db_field_name, order_type))
+            conditions.append('"{}" {}'.format(*self._get_ordering_condition(colname)))
 
         clone = copy.deepcopy(self)
         clone._order.extend(conditions)
@@ -634,12 +632,125 @@ class QuerySet(object):
         else:
             execute(qs, self._where_values())
 
+    def __eq__(self, q):
+        return set(self._where) == set(q._where)
+
+    def __ne__(self, q):
+        return not (self != q)
+
+class ResultObject(dict):
+    """
+    adds attribute access to a dictionary
+    """
+
+    def __getattr__(self, item):
+        try:
+            return self[item]
+        except KeyError:
+            raise AttributeError
+
+class SimpleQuerySet(AbstractQuerySet):
+    """
+
+    """
+
+    def _get_select_statement(self):
+        """ Returns the fields to be returned by the select query """
+        return 'SELECT *'
+
+    def _create_result_constructor(self, names):
+        """
+        Returns a function that will be used to instantiate query results
+        """
+        def _construct_instance(values):
+            return ResultObject(zip(names, values))
+        return _construct_instance
+
+class ModelQuerySet(AbstractQuerySet):
+    """
+
+    """
+    def _validate_where_syntax(self):
+        """ Checks that a filterset will not create invalid cql """
+
+        #check that there's either a = or IN relationship with a primary key or indexed field
+        equal_ops = [w for w in self._where if isinstance(w, EqualsOperator)]
+        token_ops = [w for w in self._where if isinstance(w.value, Token)]
+        if not any([w.column.primary_key or w.column.index for w in equal_ops]) and not token_ops:
+            raise QueryException('Where clauses require either a "=" or "IN" comparison with either a primary key or indexed field')
+
+        if not self._allow_filtering:
+            #if the query is not on an indexed field
+            if not any([w.column.index for w in equal_ops]):
+                if not any([w.column.partition_key for w in equal_ops]) and not token_ops:
+                    raise QueryException('Filtering on a clustering key without a partition key is not allowed unless allow_filtering() is called on the querset')
+            if any(not w.column.partition_key for w in token_ops):
+                raise QueryException('The token() function is only supported on the partition key')
+
+
+                #TODO: abuse this to see if we can get cql to raise an exception
+
+    def _where_clause(self):
+        """ Returns a where clause based on the given filter args """
+        self._validate_where_syntax()
+        return super(ModelQuerySet, self)._where_clause()
+
+    def _get_select_statement(self):
+        """ Returns the fields to be returned by the select query """
+        fields = self.model._columns.keys()
+        if self._defer_fields:
+            fields = [f for f in fields if f not in self._defer_fields]
+        elif self._only_fields:
+            fields = self._only_fields
+        db_fields = [self.model._columns[f].db_field_name for f in fields]
+        return 'SELECT {}'.format(', '.join(['"{}"'.format(f) for f in db_fields]))
+
+    def _create_result_constructor(self, names):
+        """
+        Returns a function that will be used to instantiate query results
+        """
+        model = self.model
+        db_map = model._db_map
+        if not self._values_list:
+            def _construct_instance(values):
+                field_dict = dict((db_map.get(k, k), v) for k, v in zip(names, values))
+                instance = model(**field_dict)
+                instance._is_persisted = True
+                return instance
+            return _construct_instance
+
+        columns = [model._columns[db_map[name]] for name in names]
+        if self._flat_values_list:
+            return (lambda values: columns[0].to_python(values[0]))
+        else:
+            # result_cls = namedtuple("{}Tuple".format(self.model.__name__), names)
+            return (lambda values: map(lambda (c, v): c.to_python(v), zip(columns, values)))
+
+    def _get_ordering_condition(self, colname):
+        colname, order_type = super(ModelQuerySet, self)._get_ordering_condition(colname)
+
+        column = self.model._columns.get(colname)
+        if column is None:
+            raise QueryException("Can't resolve the column name: '{}'".format(colname))
+
+        #validate the column selection
+        if not column.primary_key:
+            raise QueryException(
+                "Can't order on '{}', can only order on (clustered) primary keys".format(colname))
+
+        pks = [v for k, v in self.model._columns.items() if v.primary_key]
+        if column == pks[0]:
+            raise QueryException(
+                "Can't order by the first primary key (partition key), clustering (secondary) keys only")
+
+        return column.db_field_name, order_type
+
     def values_list(self, *fields, **kwargs):
         """ Instructs the query set to return tuples, not model instance """
         flat = kwargs.pop('flat', False)
         if kwargs:
             raise TypeError('Unexpected keyword arguments to values_list: %s'
-                    % (kwargs.keys(),))
+                            % (kwargs.keys(),))
         if flat and len(fields) > 1:
             raise TypeError("'flat' is not valid when values_list is called with more than one field.")
         clone = self.only(fields)
@@ -647,11 +758,6 @@ class QuerySet(object):
         clone._flat_values_list = flat
         return clone
 
-    def __eq__(self, q):
-        return set(self._where) == set(q._where)
-
-    def __ne__(self, q):
-        return not (self != q)
 
 class DMLQuery(object):
     """
